import _plotly_utils.basevalidators


class TraceorderValidator(_plotly_utils.basevalidators.FlaglistValidator):

    def __init__(
        self, plotly_name='traceorder', parent_name='layout.legend', **kwargs
    ):
        super(TraceorderValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='legend',
            extras=['normal'],
            flags=['reversed', 'grouped'],
            role='style',
            **kwargs
        )



import _plotly_utils.basevalidators


class DomainValidator(_plotly_utils.basevalidators.CompoundValidator):

    def __init__(self, plotly_name='domain', parent_name='table', **kwargs):
        super(DomainValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            data_class_str='Domain',
            data_docs="""
            column
                If there is a layout grid, use the domain for
                this column in the grid for this table trace .
            row
                If there is a layout grid, use the domain for
                this row in the grid for this table trace .
            x
                Sets the horizontal domain of this table trace
                (in plot fraction).
            y
                Sets the vertical domain of this table trace
                (in plot fraction).
""",
            **kwargs
        )



import _plotly_utils.basevalidators


class StartarrowsizeValidator(_plotly_utils.basevalidators.NumberValidator):

    def __init__(
        self,
        plotly_name='startarrowsize',
        parent_name='layout.annotation',
        **kwargs
    ):
        super(StartarrowsizeValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='calc+arraydraw',
            min=0.3,
            role='style',
            **kwargs
        )



import _plotly_utils.basevalidators


class TicktextValidator(_plotly_utils.basevalidators.DataArrayValidator):

    def __init__(
        self,
        plotly_name='ticktext',
        parent_name='layout.scene.zaxis',
        **kwargs
    ):
        super(TicktextValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='plot',
            role='data',
            **kwargs
        )
